@@ -1,7 +1,8 @@
-/* 
+/*
  *   Gnome Nibbles: Gnome Worm Game
- *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
- * 
+ *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>,
+ *              Guillaume Beland <guillaume.beland@gmail.com>
+ *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -20,24 +21,27 @@
 #ifndef _MAIN_H_
 #define _MAIN_H_
 
-#include <games-scores.h>
+#include <libgames-support/games-scores.h>
 
-#define MAIN_PAGE           	0
-#define NETWORK_PAGE           	1
+#include "gnibbles.h"
+
+#define MAIN_PAGE 0
+#define NETWORK_PAGE 1
 
 
 gboolean ggz_network_mode;
 int player_id;
 int num_players;
 int seat;
-int seats[4];
-char names[4][17];
+int seats[NUMWORMS];
+char names[NUMWORMS][17];
 
-gint game_running (void);
-gint pause_game_cb (GtkAction * action, gpointer data);
+gboolean game_running (void);
+gboolean pause_game_cb (GtkAction * action, gpointer data);
 void end_game (gboolean);
-gint new_game (void);
-gint main_loop (gpointer data);
+
+gboolean new_game (void);
+gboolean main_loop (gpointer data);
 
 extern GamesScores *highscores;
 extern GtkWidget *notebook;
